@@ -7,6 +7,8 @@ from threading import Thread
 logger = logging.getLogger(__name__)
 
 
+# TODO 需要增加异常输出
+
 class Coro(Thread):
     def __init__(self, name='coroThread', sem=40, daemon=False):
         """
@@ -18,7 +20,9 @@ class Coro(Thread):
         super().__init__(name=name, daemon=daemon)
         self.loop = asyncio.new_event_loop()
         self.tasks = {}
-        self.sem = asyncio.Semaphore(sem, loop=self.loop)
+        # self.loop.set_exception_handler(self.custom_exception_handler)
+        self._sem_count = sem
+        self.sem = None
 
     def __getitem__(self, item):
         try:
@@ -45,16 +49,18 @@ class Coro(Thread):
             self.loop.run_until_complete(self.loop.shutdown_asyncgens())
             self.loop.close()
 
-    async def sem_task(self, coro, sem):
+    async def sem_task(self, coro):
         # 对task增加信号量，限制同一时间正在执行的任务数
-        async with sem:
+        if not self.sem:
+            self.sem = asyncio.Semaphore(self._sem_count)
+        async with self.sem:
             return await coro
 
     def add_task(self, coro, name=None, sem=False):
         if name in self.tasks:
             return False
         if sem:
-            task = self.loop.create_task(self.sem_task(coro, self.sem))
+            task = self.loop.create_task(self.sem_task(coro))
         else:
             task = self.loop.create_task(coro, name=name)
         self.loop._csock.send(b'\0')
@@ -80,7 +86,6 @@ class Coro(Thread):
             res = '任务已取消'
         except Exception as e:
             res = str(e)
-        del self.tasks[name]
         return res
 
     def is_done(self, name):
