@@ -23,8 +23,8 @@ def md5(s, salt='', encoding='utf-8') -> str:
 
 
 def base64Encode(s) -> bytes:
-    s = str(s)
-    return base64.b64encode(s.encode('utf-8'))
+    b = str(s).encode('utf-8')
+    return bytes2base64(b)
 
 
 def base64Decode(s) -> str:
@@ -32,6 +32,10 @@ def base64Decode(s) -> str:
     return base64.b64decode(s).decode('utf-8')
 
 
+def bytes2base64(b: bytes):
+    return base64.b64encode(b)
+
+
 def bytes_decode(b: bytes, default='utf-8') -> str:
     """bytes自动解码,可以使用默认值，默认值失败就会使用cchardet尝试解码"""
     import cchardet
