@@ -25,13 +25,14 @@ class Mysql(object):
         try:
             self.db.ping(reconnect=True)
             self.db.select_db(self.current_db)
-            sql = sql.lower()
+            # sql = sql.lower()
             self.cursor.execute(sql)
+            method = sql.split()[0]
 
-            if sql.startswith(('insert', 'update', 'delete')):
+            if method.startswith(('insert', 'update', 'delete')):
                 self.db.commit()
                 return True
-            elif sql.startswith('select'):
+            elif method.startswith('select'):
                 return list(self.cursor.fetchall())
             else:
                 self.db.commit()
